# flake8: noqa

# import apis into api package
from daiedge_middleware_client.api.access_control_api import AccessControlApi
from daiedge_middleware_client.api.auth_api import AuthApi
from daiedge_middleware_client.api.identity_api import IdentityApi
from daiedge_middleware_client.api.license_api import LicenseApi
from daiedge_middleware_client.api.marketplace_api import MarketplaceApi
from daiedge_middleware_client.api.policy_api import PolicyApi
from daiedge_middleware_client.api.register_ai_model_api import RegisterAiModelApi
from daiedge_middleware_client.api.register_benchmark_api import RegisterBenchmarkApi
from daiedge_middleware_client.api.register_dataset_api import RegisterDatasetApi
from daiedge_middleware_client.api.register_hardware_api import RegisterHardwareApi
from daiedge_middleware_client.api.reward_manager_api import RewardManagerApi
from daiedge_middleware_client.api.role_management_api import RoleManagementApi
from daiedge_middleware_client.api.system_pause_api import SystemPauseApi
from daiedge_middleware_client.api.tokens_api import TokensApi
from daiedge_middleware_client.api.users_api import UsersApi
from daiedge_middleware_client.api.vc_api import VcApi
from daiedge_middleware_client.api.wallet_api import WalletApi

