# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.register_benchmark_list import RegisterBenchmarkList

class TestRegisterBenchmarkList(unittest.TestCase):
    """RegisterBenchmarkList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RegisterBenchmarkList:
        """Test RegisterBenchmarkList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RegisterBenchmarkList`
        """
        model = RegisterBenchmarkList()
        if include_optional:
            return RegisterBenchmarkList(
                benchmarks = [
                    daiedge_middleware_client.models.register_benchmark_item.RegisterBenchmarkItem(
                        model_hash = '', 
                        dataset_hash = '', 
                        device_id = '', 
                        target = '', 
                        runtime = '', 
                        user_did = '', 
                        created = 1.337, 
                        zenodo_deposition_id = '', 
                        zenodo_doi = '', 
                        zenodo_file_url = '', 
                        report_hash = '', )
                    ],
                page = 1.337,
                total_pages = 1.337,
                total = 1.337
            )
        else:
            return RegisterBenchmarkList(
                benchmarks = [
                    daiedge_middleware_client.models.register_benchmark_item.RegisterBenchmarkItem(
                        model_hash = '', 
                        dataset_hash = '', 
                        device_id = '', 
                        target = '', 
                        runtime = '', 
                        user_did = '', 
                        created = 1.337, 
                        zenodo_deposition_id = '', 
                        zenodo_doi = '', 
                        zenodo_file_url = '', 
                        report_hash = '', )
                    ],
        )
        """

    def testRegisterBenchmarkList(self):
        """Test RegisterBenchmarkList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
