# coding: utf-8

# flake8: noqa
"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from daiedge_middleware_client.models.accelerator import Accelerator
from daiedge_middleware_client.models.accept_vc_request_body import AcceptVCRequestBody
from daiedge_middleware_client.models.add_delegate_body import AddDelegateBody
from daiedge_middleware_client.models.authentication_context import AuthenticationContext
from daiedge_middleware_client.models.authentication_context_error import AuthenticationContextError
from daiedge_middleware_client.models.buy_resource_body import BuyResourceBody
from daiedge_middleware_client.models.cpu import CPU
from daiedge_middleware_client.models.cpu_specs_item import CPUSpecsItem
from daiedge_middleware_client.models.change_owner_body import ChangeOwnerBody
from daiedge_middleware_client.models.check_access_response import CheckAccessResponse
from daiedge_middleware_client.models.cost import Cost
from daiedge_middleware_client.models.create_ai_model_response import CreateAIModelResponse
from daiedge_middleware_client.models.create_benchmark_response import CreateBenchmarkResponse
from daiedge_middleware_client.models.create_did_policy_body import CreateDIDPolicyBody
from daiedge_middleware_client.models.create_dataset_response import CreateDatasetResponse
from daiedge_middleware_client.models.create_hardware_policy_body import CreateHardwarePolicyBody
from daiedge_middleware_client.models.create_hardware_response import CreateHardwareResponse
from daiedge_middleware_client.models.create_role_body import CreateRoleBody
from daiedge_middleware_client.models.create_role_response import CreateRoleResponse
from daiedge_middleware_client.models.decode_credential_body import DecodeCredentialBody
from daiedge_middleware_client.models.default_spec_item import DefaultSpecItem
from daiedge_middleware_client.models.default_specs_memory import DefaultSpecsMemory
from daiedge_middleware_client.models.delete_hardware_body import DeleteHardwareBody
from daiedge_middleware_client.models.edit_did_policy_body import EditDIDPolicyBody
from daiedge_middleware_client.models.edit_hardware_policy_body import EditHardwarePolicyBody
from daiedge_middleware_client.models.engine import Engine
from daiedge_middleware_client.models.error_response import ErrorResponse
from daiedge_middleware_client.models.generate_key_pair_body import GenerateKeyPairBody
from daiedge_middleware_client.models.get_register_ai_model_item import GetRegisterAIModelItem
from daiedge_middleware_client.models.get_register_benchmark_item import GetRegisterBenchmarkItem
from daiedge_middleware_client.models.get_register_dataset_item import GetRegisterDatasetItem
from daiedge_middleware_client.models.get_register_hardware_item import GetRegisterHardwareItem
from daiedge_middleware_client.models.get_reward_by_rule import GetRewardByRule
from daiedge_middleware_client.models.gran_role_body import GranRoleBody
from daiedge_middleware_client.models.grant_access_body import GrantAccessBody
from daiedge_middleware_client.models.grant_revoke_issuer_role_body import GrantRevokeIssuerRoleBody
from daiedge_middleware_client.models.hardware_access_item import HardwareAccessItem
from daiedge_middleware_client.models.hardware_access_list import HardwareAccessList
from daiedge_middleware_client.models.hardware_policy_response import HardwarePolicyResponse
from daiedge_middleware_client.models.hardware_spec import HardwareSpec
from daiedge_middleware_client.models.has_role_response import HasRoleResponse
from daiedge_middleware_client.models.identity_owner_response import IdentityOwnerResponse
from daiedge_middleware_client.models.license_request_item import LicenseRequestItem
from daiedge_middleware_client.models.license_request_list import LicenseRequestList
from daiedge_middleware_client.models.listed_resource_item import ListedResourceItem
from daiedge_middleware_client.models.listed_resource_list import ListedResourceList
from daiedge_middleware_client.models.login_error_bad_request import LoginErrorBadRequest
from daiedge_middleware_client.models.login_error_forbidden import LoginErrorForbidden
from daiedge_middleware_client.models.login_request import LoginRequest
from daiedge_middleware_client.models.login_response import LoginResponse
from daiedge_middleware_client.models.memory import Memory
from daiedge_middleware_client.models.mint_tokens_body import MintTokensBody
from daiedge_middleware_client.models.pause_contract_body import PauseContractBody
from daiedge_middleware_client.models.pause_system_body import PauseSystemBody
from daiedge_middleware_client.models.power import Power
from daiedge_middleware_client.models.power_item_details import PowerItemDetails
from daiedge_middleware_client.models.register_ai_model_body import RegisterAIModelBody
from daiedge_middleware_client.models.register_ai_model_item import RegisterAIModelItem
from daiedge_middleware_client.models.register_ai_model_list import RegisterAIModelList
from daiedge_middleware_client.models.register_access_body import RegisterAccessBody
from daiedge_middleware_client.models.register_benchmark_body import RegisterBenchmarkBody
from daiedge_middleware_client.models.register_benchmark_item import RegisterBenchmarkItem
from daiedge_middleware_client.models.register_benchmark_list import RegisterBenchmarkList
from daiedge_middleware_client.models.register_data_set_item import RegisterDataSetItem
from daiedge_middleware_client.models.register_data_set_list import RegisterDataSetList
from daiedge_middleware_client.models.register_dataset_body import RegisterDatasetBody
from daiedge_middleware_client.models.register_hardware_body import RegisterHardwareBody
from daiedge_middleware_client.models.register_hardware_item import RegisterHardwareItem
from daiedge_middleware_client.models.register_hardware_list import RegisterHardwareList
from daiedge_middleware_client.models.remove_did_policy_body import RemoveDIDPolicyBody
from daiedge_middleware_client.models.remove_hardware_policy_body import RemoveHardwarePolicyBody
from daiedge_middleware_client.models.remove_listed_resource_body import RemoveListedResourceBody
from daiedge_middleware_client.models.remove_reward_rule_body import RemoveRewardRuleBody
from daiedge_middleware_client.models.request_user_license_body import RequestUserLicenseBody
from daiedge_middleware_client.models.request_vc_body import RequestVCBody
from daiedge_middleware_client.models.revoke_access_body import RevokeAccessBody
from daiedge_middleware_client.models.revoke_delegate_body import RevokeDelegateBody
from daiedge_middleware_client.models.revoke_issuer_role_body import RevokeIssuerRoleBody
from daiedge_middleware_client.models.revoke_license_body import RevokeLicenseBody
from daiedge_middleware_client.models.revoke_role_body import RevokeRoleBody
from daiedge_middleware_client.models.reward_history_item import RewardHistoryItem
from daiedge_middleware_client.models.reward_history_list import RewardHistoryList
from daiedge_middleware_client.models.reward_manual_body import RewardManualBody
from daiedge_middleware_client.models.reward_off_chain_body import RewardOffChainBody
from daiedge_middleware_client.models.reward_on_chain_body import RewardOnChainBody
from daiedge_middleware_client.models.role_management_item import RoleManagementItem
from daiedge_middleware_client.models.role_management_list import RoleManagementList
from daiedge_middleware_client.models.sell_resource_body import SellResourceBody
from daiedge_middleware_client.models.set_benchmark_result_body import SetBenchmarkResultBody
from daiedge_middleware_client.models.set_hardware_body import SetHardwareBody
from daiedge_middleware_client.models.set_reward_rule_body import SetRewardRuleBody
from daiedge_middleware_client.models.signup_error_bad_request import SignupErrorBadRequest
from daiedge_middleware_client.models.signup_request import SignupRequest
from daiedge_middleware_client.models.signup_response import SignupResponse
from daiedge_middleware_client.models.software_spec import SoftwareSpec
from daiedge_middleware_client.models.storage import Storage
from daiedge_middleware_client.models.storage_specs_item import StorageSpecsItem
from daiedge_middleware_client.models.supported_application import SupportedApplication
from daiedge_middleware_client.models.supported_application_details import SupportedApplicationDetails
from daiedge_middleware_client.models.system_status import SystemStatus
from daiedge_middleware_client.models.unpause_contract_body import UnpauseContractBody
from daiedge_middleware_client.models.unpause_system_body import UnpauseSystemBody
from daiedge_middleware_client.models.update_ai_model_body import UpdateAIModelBody
from daiedge_middleware_client.models.update_dataset_body import UpdateDatasetBody
from daiedge_middleware_client.models.update_hardware_body import UpdateHardwareBody
from daiedge_middleware_client.models.use_license_item import UseLicenseItem
from daiedge_middleware_client.models.user_did_item import UserDIDItem
from daiedge_middleware_client.models.user_did_list import UserDIDList
from daiedge_middleware_client.models.user_did_resolve_response import UserDIDResolveResponse
from daiedge_middleware_client.models.user_license_list import UserLicenseList
from daiedge_middleware_client.models.user_vc_item import UserVCItem
from daiedge_middleware_client.models.user_vc_list import UserVCList
from daiedge_middleware_client.models.vc_claim import VCClaim
from daiedge_middleware_client.models.vc_request_item import VCRequestItem
from daiedge_middleware_client.models.vc_request_list import VCRequestList
from daiedge_middleware_client.models.validate_license_request_body import ValidateLicenseRequestBody
from daiedge_middleware_client.models.verify_credential_body import VerifyCredentialBody
from daiedge_middleware_client.models.verify_credential_response import VerifyCredentialResponse
from daiedge_middleware_client.models.verify_presentation_body import VerifyPresentationBody
from daiedge_middleware_client.models.wallet_change_password_bad_request import WalletChangePasswordBadRequest
from daiedge_middleware_client.models.wallet_change_password_body import WalletChangePasswordBody
from daiedge_middleware_client.models.wallet_create_bad_request import WalletCreateBadRequest
from daiedge_middleware_client.models.wallet_create_body import WalletCreateBody
from daiedge_middleware_client.models.wallet_edit_bad_request import WalletEditBadRequest
from daiedge_middleware_client.models.wallet_edit_body import WalletEditBody
from daiedge_middleware_client.models.wallet_export_bad_request import WalletExportBadRequest
from daiedge_middleware_client.models.wallet_export_body import WalletExportBody
from daiedge_middleware_client.models.wallet_export_response import WalletExportResponse
from daiedge_middleware_client.models.wallet_info import WalletInfo

