# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.api.reward_manager_api import RewardManagerApi


class TestRewardManagerApi(unittest.IsolatedAsyncioTestCase):
    """RewardManagerApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = RewardManagerApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_rewards_get(self) -> None:
        """Test case for rewards_get

        """
        pass

    async def test_rewards_get_reward_by_rule_aid_get(self) -> None:
        """Test case for rewards_get_reward_by_rule_aid_get

        """
        pass

    async def test_rewards_remove_reward_rule_post(self) -> None:
        """Test case for rewards_remove_reward_rule_post

        """
        pass

    async def test_rewards_reward_manual_post(self) -> None:
        """Test case for rewards_reward_manual_post

        """
        pass

    async def test_rewards_reward_off_chain_post(self) -> None:
        """Test case for rewards_reward_off_chain_post

        """
        pass

    async def test_rewards_reward_on_chain_post(self) -> None:
        """Test case for rewards_reward_on_chain_post

        """
        pass

    async def test_rewards_set_reward_rule_post(self) -> None:
        """Test case for rewards_set_reward_rule_post

        """
        pass


if __name__ == '__main__':
    unittest.main()
