# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class UseLicenseItem(BaseModel):
    """
    UseLicenseItem
    """ # noqa: E501
    id: StrictStr = Field(description="License ID")
    uid: StrictStr = Field(description="User ID")
    did: StrictStr = Field(description="Device ID")
    hid: StrictStr = Field(description="Hardware ID")
    license: Dict[str, Any] = Field(description="License")
    created: Union[StrictFloat, StrictInt] = Field(description="Created timestamp")
    is_valid: Optional[StrictBool] = Field(default=None, description="True if the license is valid on blockchain", alias="isValid")
    expiration_time: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="License expiration time (timestamp in ms)", alias="expirationTime")
    type1: Optional[StrictBool] = Field(default=None, description="True if the license includes type1 usage")
    type2: Optional[StrictBool] = Field(default=None, description="True if the license includes type2 usage")
    type3: Optional[StrictBool] = Field(default=None, description="True if the license includes type3 usage")
    single_use: Optional[StrictBool] = Field(default=None, description="True if the license is single-use", alias="singleUse")
    __properties: ClassVar[List[str]] = ["id", "uid", "did", "hid", "license", "created", "isValid", "expirationTime", "type1", "type2", "type3", "singleUse"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UseLicenseItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UseLicenseItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "uid": obj.get("uid"),
            "did": obj.get("did"),
            "hid": obj.get("hid"),
            "license": obj.get("license"),
            "created": obj.get("created"),
            "isValid": obj.get("isValid"),
            "expirationTime": obj.get("expirationTime"),
            "type1": obj.get("type1"),
            "type2": obj.get("type2"),
            "type3": obj.get("type3"),
            "singleUse": obj.get("singleUse")
        })
        return _obj


