# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.revoke_access_body import RevokeAccessBody

class TestRevokeAccessBody(unittest.TestCase):
    """RevokeAccessBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RevokeAccessBody:
        """Test RevokeAccessBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RevokeAccessBody`
        """
        model = RevokeAccessBody()
        if include_optional:
            return RevokeAccessBody(
                wallet_id = '',
                password = '',
                user_did = '',
                did = '',
                resource_id = '',
                resource_type = 'ai_model'
            )
        else:
            return RevokeAccessBody(
                wallet_id = '',
                password = '',
                user_did = '',
                did = '',
                resource_id = '',
                resource_type = 'ai_model',
        )
        """

    def testRevokeAccessBody(self):
        """Test RevokeAccessBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
