# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.register_hardware_list import RegisterHardwareList

class TestRegisterHardwareList(unittest.TestCase):
    """RegisterHardwareList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RegisterHardwareList:
        """Test RegisterHardwareList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RegisterHardwareList`
        """
        model = RegisterHardwareList()
        if include_optional:
            return RegisterHardwareList(
                hardware = [
                    daiedge_middleware_client.models.register_hardware_item.RegisterHardwareItem(
                        id = '', 
                        owner = '', 
                        created = 1.337, 
                        is_implemented = True, 
                        family = '', 
                        description = '', 
                        hardware_spec = daiedge_middleware_client.models.hardware_spec.HardwareSpec(
                            cost = daiedge_middleware_client.models.cost.Cost(
                                value = 1.337, 
                                currency = '', 
                                unit = '', ), 
                            cpus = [
                                daiedge_middleware_client.models.cpu.CPU(
                                    id = '', 
                                    arch = '', 
                                    model = '', 
                                    specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                                        rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                            value = 1.337, 
                                            unit = '', 
                                            kind = '', ), 
                                        cores = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                            value = 1.337, 
                                            unit = '', 
                                            kind = '', ), 
                                        computing_power = , ), )
                                ], 
                            accelerators = [
                                daiedge_middleware_client.models.accelerator.Accelerator(
                                    id = '', 
                                    type = '', 
                                    model = '', 
                                    specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                                        rate = , 
                                        cores = , 
                                        computing_power = , ), )
                                ], 
                            memory = daiedge_middleware_client.models.memory.Memory(
                                type = '', 
                                kind = '', 
                                specs = daiedge_middleware_client.models.default_specs_memory.DefaultSpecsMemory(
                                    size = , 
                                    rate = , ), ), 
                            storage = daiedge_middleware_client.models.storage.Storage(
                                type = '', 
                                specs = daiedge_middleware_client.models.storage_specs_item.StorageSpecsItem(
                                    size = , 
                                    rate = , ), ), 
                            power = daiedge_middleware_client.models.power.Power(
                                min = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                                    value = 1.337, 
                                    unit = '', ), 
                                max = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                                    value = 1.337, 
                                    unit = '', ), ), ), 
                        software_spec = daiedge_middleware_client.models.software_spec.SoftwareSpec(
                            os = '', 
                            version = '', 
                            engines = [
                                daiedge_middleware_client.models.engine.Engine(
                                    id = '', 
                                    name = '', 
                                    family = '', 
                                    version = '', 
                                    computing_backends = [
                                        ''
                                        ], 
                                    supported_applications = [
                                        daiedge_middleware_client.models.supported_application.SupportedApplication(
                                            type = '', 
                                            details = daiedge_middleware_client.models.supported_application_details.SupportedApplicationDetails(
                                                supported_types = [
                                                    ''
                                                    ], ), )
                                        ], )
                                ], ), )
                    ],
                page = 1.337,
                total_pages = 1.337,
                total = 1.337
            )
        else:
            return RegisterHardwareList(
                hardware = [
                    daiedge_middleware_client.models.register_hardware_item.RegisterHardwareItem(
                        id = '', 
                        owner = '', 
                        created = 1.337, 
                        is_implemented = True, 
                        family = '', 
                        description = '', 
                        hardware_spec = daiedge_middleware_client.models.hardware_spec.HardwareSpec(
                            cost = daiedge_middleware_client.models.cost.Cost(
                                value = 1.337, 
                                currency = '', 
                                unit = '', ), 
                            cpus = [
                                daiedge_middleware_client.models.cpu.CPU(
                                    id = '', 
                                    arch = '', 
                                    model = '', 
                                    specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                                        rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                            value = 1.337, 
                                            unit = '', 
                                            kind = '', ), 
                                        cores = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                            value = 1.337, 
                                            unit = '', 
                                            kind = '', ), 
                                        computing_power = , ), )
                                ], 
                            accelerators = [
                                daiedge_middleware_client.models.accelerator.Accelerator(
                                    id = '', 
                                    type = '', 
                                    model = '', 
                                    specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                                        rate = , 
                                        cores = , 
                                        computing_power = , ), )
                                ], 
                            memory = daiedge_middleware_client.models.memory.Memory(
                                type = '', 
                                kind = '', 
                                specs = daiedge_middleware_client.models.default_specs_memory.DefaultSpecsMemory(
                                    size = , 
                                    rate = , ), ), 
                            storage = daiedge_middleware_client.models.storage.Storage(
                                type = '', 
                                specs = daiedge_middleware_client.models.storage_specs_item.StorageSpecsItem(
                                    size = , 
                                    rate = , ), ), 
                            power = daiedge_middleware_client.models.power.Power(
                                min = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                                    value = 1.337, 
                                    unit = '', ), 
                                max = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                                    value = 1.337, 
                                    unit = '', ), ), ), 
                        software_spec = daiedge_middleware_client.models.software_spec.SoftwareSpec(
                            os = '', 
                            version = '', 
                            engines = [
                                daiedge_middleware_client.models.engine.Engine(
                                    id = '', 
                                    name = '', 
                                    family = '', 
                                    version = '', 
                                    computing_backends = [
                                        ''
                                        ], 
                                    supported_applications = [
                                        daiedge_middleware_client.models.supported_application.SupportedApplication(
                                            type = '', 
                                            details = daiedge_middleware_client.models.supported_application_details.SupportedApplicationDetails(
                                                supported_types = [
                                                    ''
                                                    ], ), )
                                        ], )
                                ], ), )
                    ],
        )
        """

    def testRegisterHardwareList(self):
        """Test RegisterHardwareList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
