# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Union
from daiedge_middleware_client.models.hardware_spec import HardwareSpec
from daiedge_middleware_client.models.software_spec import SoftwareSpec
from typing import Optional, Set
from typing_extensions import Self

class GetRegisterHardwareItem(BaseModel):
    """
    GetRegisterHardwareItem
    """ # noqa: E501
    owner: StrictStr = Field(description="Owner user DID")
    hash: StrictStr = Field(description="Register hardware hash")
    created: Union[StrictFloat, StrictInt] = Field(description="Creation timestamp")
    is_implemented: StrictBool = Field(description="Indicates if the hardware is implemented")
    family: StrictStr = Field(description="Hardware family or category (e.g., \"rpi4b\")")
    description: StrictStr = Field(description="Detailed description of the hardware (e.g., \"Raspberry Pi 4B with 4GB RAM\")")
    hardware_spec: HardwareSpec
    software_spec: SoftwareSpec
    __properties: ClassVar[List[str]] = ["owner", "hash", "created", "is_implemented", "family", "description", "hardware_spec", "software_spec"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GetRegisterHardwareItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of hardware_spec
        if self.hardware_spec:
            _dict['hardware_spec'] = self.hardware_spec.to_dict()
        # override the default output from pydantic by calling `to_dict()` of software_spec
        if self.software_spec:
            _dict['software_spec'] = self.software_spec.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GetRegisterHardwareItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "owner": obj.get("owner"),
            "hash": obj.get("hash"),
            "created": obj.get("created"),
            "is_implemented": obj.get("is_implemented"),
            "family": obj.get("family"),
            "description": obj.get("description"),
            "hardware_spec": HardwareSpec.from_dict(obj["hardware_spec"]) if obj.get("hardware_spec") is not None else None,
            "software_spec": SoftwareSpec.from_dict(obj["software_spec"]) if obj.get("software_spec") is not None else None
        })
        return _obj


