# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.software_spec import SoftwareSpec

class TestSoftwareSpec(unittest.TestCase):
    """SoftwareSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SoftwareSpec:
        """Test SoftwareSpec
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SoftwareSpec`
        """
        model = SoftwareSpec()
        if include_optional:
            return SoftwareSpec(
                os = '',
                version = '',
                engines = [
                    daiedge_middleware_client.models.engine.Engine(
                        id = '', 
                        name = '', 
                        family = '', 
                        version = '', 
                        computing_backends = [
                            ''
                            ], 
                        supported_applications = [
                            daiedge_middleware_client.models.supported_application.SupportedApplication(
                                type = '', 
                                details = daiedge_middleware_client.models.supported_application_details.SupportedApplicationDetails(
                                    supported_types = [
                                        ''
                                        ], ), )
                            ], )
                    ]
            )
        else:
            return SoftwareSpec(
                os = '',
                version = '',
                engines = [
                    daiedge_middleware_client.models.engine.Engine(
                        id = '', 
                        name = '', 
                        family = '', 
                        version = '', 
                        computing_backends = [
                            ''
                            ], 
                        supported_applications = [
                            daiedge_middleware_client.models.supported_application.SupportedApplication(
                                type = '', 
                                details = daiedge_middleware_client.models.supported_application_details.SupportedApplicationDetails(
                                    supported_types = [
                                        ''
                                        ], ), )
                            ], )
                    ],
        )
        """

    def testSoftwareSpec(self):
        """Test SoftwareSpec"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
