# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.api.marketplace_api import MarketplaceApi


class TestMarketplaceApi(unittest.IsolatedAsyncioTestCase):
    """MarketplaceApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = MarketplaceApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_marketplace_buy_post(self) -> None:
        """Test case for marketplace_buy_post

        """
        pass

    async def test_marketplace_delete(self) -> None:
        """Test case for marketplace_delete

        """
        pass

    async def test_marketplace_get(self) -> None:
        """Test case for marketplace_get

        """
        pass

    async def test_marketplace_sell_post(self) -> None:
        """Test case for marketplace_sell_post

        """
        pass


if __name__ == '__main__':
    unittest.main()
