# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.power import Power

class TestPower(unittest.TestCase):
    """Power unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Power:
        """Test Power
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Power`
        """
        model = Power()
        if include_optional:
            return Power(
                min = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                    value = 1.337, 
                    unit = '', ),
                max = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                    value = 1.337, 
                    unit = '', )
            )
        else:
            return Power(
                min = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                    value = 1.337, 
                    unit = '', ),
                max = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                    value = 1.337, 
                    unit = '', ),
        )
        """

    def testPower(self):
        """Test Power"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
