# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.storage_specs_item import StorageSpecsItem

class TestStorageSpecsItem(unittest.TestCase):
    """StorageSpecsItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StorageSpecsItem:
        """Test StorageSpecsItem
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StorageSpecsItem`
        """
        model = StorageSpecsItem()
        if include_optional:
            return StorageSpecsItem(
                size = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                    value = 1.337, 
                    unit = '', 
                    kind = '', ),
                rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                    value = 1.337, 
                    unit = '', 
                    kind = '', )
            )
        else:
            return StorageSpecsItem(
                size = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                    value = 1.337, 
                    unit = '', 
                    kind = '', ),
                rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                    value = 1.337, 
                    unit = '', 
                    kind = '', ),
        )
        """

    def testStorageSpecsItem(self):
        """Test StorageSpecsItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
